"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.generateMermaidGraph = exports.sortPackageFiles = void 0;
const graph_data_structure_1 = require("graph-data-structure");
function sortPackageFiles(depsBetweenFiles, packageFiles) {
    const result = [];
    const graph = (0, graph_data_structure_1.Graph)();
    depsBetweenFiles.forEach(({ sourceFile, outputFile }) => {
        graph.addEdge(sourceFile, outputFile);
    });
    const sorted = graph.topologicalSort();
    for (const file of sorted) {
        if (packageFiles.has(file)) {
            const packageFile = packageFiles.get(file);
            const sortedLockFiles = [];
            // TODO(not7cd): this needs better test case
            for (const lockFile of packageFile.lockFiles) {
                if (sorted.includes(lockFile)) {
                    sortedLockFiles.push(lockFile);
                }
            }
            packageFile.lockFiles = sortedLockFiles;
            result.push(packageFile);
        }
    }
    // istanbul ignore if: should never happen
    if (result.length !== packageFiles.size) {
        throw new Error('Topological sort failed to include all package files');
    }
    return result;
}
exports.sortPackageFiles = sortPackageFiles;
function generateMermaidGraph(depsBetweenFiles, lockFileArgs) {
    const lockFiles = [];
    for (const lockFile of lockFileArgs.keys()) {
        // TODO: add extra args to the lock file ${extraArgs ? '\n' + extraArgs : ''}
        // const extraArgs = pipCompileArgs.extra
        //   ?.map((v) => '--extra=' + v)
        //   .join('\n');
        lockFiles.push(`  ${lockFile}[[${lockFile}]]`);
    }
    const edges = depsBetweenFiles.map(({ sourceFile, outputFile, type }) => {
        return `  ${sourceFile} -${type === 'constraint' ? '.' : ''}-> ${outputFile}`;
    });
    return `graph TD\n${lockFiles.join('\n')}\n${edges.join('\n')}`;
}
exports.generateMermaidGraph = generateMermaidGraph;
//# sourceMappingURL=utils.js.map